Deserialization

Trait Deserialization 

pub trait Deserialization<FormatType: Trait>: Sized {
    type Deserializer: Trait<Self, FormatType>;
}
A trait that associates a type with its flexpiler Deseriaizer type

The flexpiler_derive macro will generate a custom Deserializer type and then impl this trait for your type, associating it with the auto-generated deserializer type.

Required Associated Types

type Deserializer: Trait<Self, FormatType>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl Deserialization<Format> for String

Source

impl Deserialization<Format> for i32

Source

impl Deserialization<Format> for usize

Source

impl<DataType, ErrorType> Deserialization<Format> for Result<DataType, ErrorType>
where DataType: Deserialization<Format> + Trait, ErrorType: Deserialization<Format> + Trait,

Source

impl<DataType> Deserialization<Format> for Option<DataType>
where DataType: Deserialization<Format> + Trait,

Source

impl<DataType> Deserialization<Format> for Vec<DataType>
where DataType: Deserialization<Format> + Trait,

Implementors